@@ -84,6 +84,16 @@ class CollectionQueryset(object):
 
         return self
 
+    def order_by(self, field, order):
+        """
+        """
+
+        self._has_cache = False
+
+        self._query.order_by(field=field, order=order)
+
+        return self
+
     def _clone(self):
         """
         """
@@ -179,6 +189,17 @@ class CollectionModelManager(object):
 
         return model
 
+    def get_or_create(self, **kwargs):
+        """
+        """
+
+        model = self.get(**kwargs)
+
+        if model is None:
+            model = self._model_class()
+
+        return model
+
     def all(self):
         """
         """
