@@ -266,6 +266,34 @@ class AqlQueryTestCase(ExtendedTestCase):
         self.assertDocumentsEqual(doc2, self.col1_doc3)
         self.assertDocumentsEqual(doc3, self.col1_doc1)
 
+    def test_limit_simple_list(self):
+        q = Query()
+        q.append_collection(self.test_1_col.name)
+        q.order_by('little_number')
+        q.limit(count=1)
+
+        docs = q.execute()
+
+        self.assertEqual(len(docs), 1)
+
+        doc1 = docs[0]
+
+        self.assertDocumentsEqual(doc1, self.col1_doc2)
+
+    def test_limit_with_start_simple_list(self):
+        q = Query()
+        q.append_collection(self.test_1_col.name)
+        q.order_by('little_number')
+        q.limit(count=1, start=1)
+
+        docs = q.execute()
+
+        self.assertEqual(len(docs), 1)
+
+        doc1 = docs[0]
+
+        self.assertDocumentsEqual(doc1, self.col1_doc3)
+
 
 class SimpleQueryTestCase(ExtendedTestCase):
     def setUp(self):
@@ -1044,6 +1072,156 @@ class CollectionModelManagerTestCase(unittest.TestCase):
 
         TestModel.destroy()
 
+    def test_get_or_create_model(self):
+
+        class TestModel(CollectionModel):
+            active = BooleanField(null=False, default=False)
+
+        TestModel.init()
+
+        all_models = TestModel.objects.all()
+        self.assertEqual(len(all_models), 0)
+
+        model = TestModel.objects.get_or_create(active=True)
+
+        self.assertEqual(model.active, False)
+
+        model.active = True
+        model.save()
+
+        model = TestModel.objects.get_or_create(active=True)
+
+        self.assertEqual(model.active, True)
+
+        all_models = TestModel.objects.all()
+        self.assertEqual(len(all_models), 1)
+
+        TestModel.destroy()
+
+    def test_order_by_model_field_attribute_asc(self):
+
+        class TestModel(CollectionModel):
+            order = NumberField()
+
+        TestModel.init()
+
+        model1 = TestModel()
+        model1.order = 3
+        model1.save()
+
+        model2 = TestModel()
+        model2.order = 1
+        model2.save()
+
+        model3 = TestModel()
+        model3.order = 2
+        model3.save()
+
+        all_models = TestModel.objects.all().order_by(field='order', order=Query.SORTING_ASC)
+
+        self.assertEqual(len(all_models), 3)
+
+        model = all_models[0]
+        self.assertEqual(model.id, model2.id)
+
+        model = all_models[1]
+        self.assertEqual(model.id, model3.id)
+
+        model = all_models[2]
+        self.assertEqual(model.id, model1.id)
+
+        TestModel.destroy()
+
+    def test_order_by_model_field_attribute_desc(self):
+
+        class TestModel(CollectionModel):
+            order = NumberField()
+
+        TestModel.init()
+
+        model1 = TestModel()
+        model1.order = 3
+        model1.save()
+
+        model2 = TestModel()
+        model2.order = 1
+        model2.save()
+
+        model3 = TestModel()
+        model3.order = 2
+        model3.save()
+
+        all_models = TestModel.objects.all().order_by(field='order', order=Query.SORTING_DESC)
+
+        self.assertEqual(len(all_models), 3)
+
+        model = all_models[0]
+        self.assertEqual(model.id, model1.id)
+
+        model = all_models[1]
+        self.assertEqual(model.id, model3.id)
+
+        model = all_models[2]
+        self.assertEqual(model.id, model2.id)
+
+        TestModel.destroy()
+
+    def test_limit_model_list(self):
+
+        class TestModel(CollectionModel):
+            order = NumberField()
+
+        TestModel.init()
+
+        model1 = TestModel()
+        model1.order = 3
+        model1.save()
+
+        model2 = TestModel()
+        model2.order = 1
+        model2.save()
+
+        model3 = TestModel()
+        model3.order = 2
+        model3.save()
+
+        all_models = TestModel.objects.all().order_by(field='order', order=Query.SORTING_ASC).limit(1)
+
+        self.assertEqual(len(all_models), 1)
+
+        model = all_models[0]
+        self.assertEqual(model.id, model2.id)
+
+        TestModel.destroy()
+
+    def test_limit_with_start_model_list(self):
+
+        class TestModel(CollectionModel):
+            order = NumberField()
+
+        TestModel.init()
+
+        model1 = TestModel()
+        model1.order = 3
+        model1.save()
+
+        model2 = TestModel()
+        model2.order = 1
+        model2.save()
+
+        model3 = TestModel()
+        model3.order = 2
+        model3.save()
+
+        all_models = TestModel.objects.all().order_by(field='order', order=Query.SORTING_ASC).limit(1, 1)
+
+        self.assertEqual(len(all_models), 1)
+
+        model = all_models[0]
+        self.assertEqual(model.id, model3.id)
+
+        TestModel.destroy()
+
 
 class CollectionModelForeignKeyFieldTestCase(unittest.TestCase):
     def setUp(self):
@@ -1767,6 +1945,8 @@ class EndpointTestCase(unittest.TestCase):
             self.assertTrue('endpoint' in endpoint)
             self.assertTrue('databases' in endpoint)
 
+
+    # TODO: Take a look at it in the documentation in ArangoDB
     # def test_create_and_delete_endpoint(self):
     #
     #     endpoint_url = 'tcp://127.0.0.1:2211'
